package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````H"4```````!``````````$BQ````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````&@9````````:!D`````````
M$`````````$````%`````"``````````(``````````@````````53X`````
M``!5/@`````````0`````````0````0`````8`````````!@`````````&``
M```````P2````````#!(`````````!`````````!````!@```.BK````````
MZ+L```````#HNP```````$`$````````L`0`````````$`````````(````&
M````^*L```````#XNP```````/B[``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``#`H````````,"@````````P*````````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````Z*L```````#HNP```````.B[````
M````&`0````````8!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50"E:=,6T'?JI\PK<O,SYL?6)")2=`0````0````
M`0```$=.50```````P````(``````````````!$````^````!`````@````@
M'!``!4`$AB@"``2`A@"$@HD`(DD@!`B8@!%!N@`""@`````^````00```$0`
M``!%````30```$X```!0`````````%,```!4````50```%<```!9````6P``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/JA;&"93\.;:PE#UF:OS&;%N9Q`./*+'$)%U>R)
M!W#3,V+;[16,)<P,.I<+I]VC:WZIG)O19<YMX*<""FL:GE`*BA!7H^#[20``
M`````````````````````````````.0````2````````````````````````
M`)8````2`````````````````````````%T!```2````````````````````
M`````%\"```2`````````````````````````#`"```2````````````````
M`````````/H````2``````````````````````````$````@````````````
M`````````````)<!```2`````````````````````````,,"```2````````
M`````````````````/`!```2`````````````````````````+$"```2````
M`````````````````````'0!```2`````````````````````````"L!```2
M`````````````````````````!L!```2`````````````````````````,T!
M```2`````````````````````````.H!```2````````````````````````
M``T!```2``````````````````````````H"```2````````````````````
M`````&\#```2`````````````````````````!`````@````````````````
M`````````'L!```2`````````````````````````.D````2````````````
M`````````````.,!```2`````````````````````````"P````@````````
M`````````````````#\"```2`````````````````````````'P"```2````
M`````````````````````/L!```2`````````````````````````$8````2
M`````````````````````````&,````6`````````````````````````$T!
M```2`````````````````````````'8````2````````````````````````
M`-,````2`````````````````````````(<````2````````````````````
M`````,4!```2`````````````````````````+X!```2````````````````
M`````````+<````2`````````````````````````!$"```2````````````
M`````````````-0!```2`````````````````````````'4"```2````````
M`````````````````#\!```2`````````````````````````*`"```2````
M`````````````````````*X!```2`````````````````````````.X````2
M`````````````````````````(8!```2`````````````````````````)D"
M```2`````````````````````````-P!```2````````````````````````
M`#X"```2`````````````````````````(0"```2````````````````````
M`````*(````2`````````````````````````&@!```2````````````````
M`````````)P!```2`````````````````````````+4!```2````````````
M`````````````"("```2`````````````````````````(L"```2````````
M`````````````````!H"```2`````````````````````````#0!```2````
M`````````````````````%0````2`````````````````````````$8"```2
M`````````````````````````)("```2`````````````````````````*0!
M```2`````````````````````````/4!```2````````````````````````
M`'@#```2``\`H$(```````#6`````````,T#```2``\`<#D````````!!P``
M`````%,"```2``\`D",````````,`@```````.\"```2``\`X"T````````)
M``````````T#```2``\`@$`````````@`@```````/,#```2``\`\"T`````
M```2`@```````+,#```0`!D`0,`````````````````````#```2``\`$#``
M```````F`````````",#```2``\`\#4```````!I`````````(0#```1`!$`
M`&`````````$`````````*`#```2``\`0%H```````"?`0```````*L#```2
M``\`T"P````````I`````````,@#```0`!D`F,```````````````````.$#
M```2``\`D#@```````#8``````````H$```2``\`8#8```````"X````````
M`),#```0`!@``,```````````````````$<#```2``\`0#````````!!`0``
M`````+D"```1`!D`0,`````````(`````````%@"```1`!D`8,`````````(
M`````````-H#```0`!@`*,`````````````````````$```1`!@`(,``````
M```(`````````)D#```2``\`H"4````````B`````````+\#```2``\`\%D`
M``````!)`````````)4#```@`!@``,```````````````````+L"```A`!D`
M0,`````````(`````````%T#```2``\`8#@````````A`````````&8"```B
M`````````````````````````#$#```2``\``"T```````#3`````````%,#
M```2``\`X%L```````!5`@```````,8````1`!D`<,`````````!````````
M`!($```2``\`D#$```````!<!`````````!?7V=M;VY?<W1A<G1?7P!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?
M8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?
M9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,
M7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V
M7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D
M:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE
M;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN
M=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`
M7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R
M<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T=6ED
M`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M
M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,X
M`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN
M:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H
M`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`
M1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,
M24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#7S(N,BXU`````0`!``$``@`#
M``$``0`"``0``@`"``(``0`!``(``@`!``(``@`!``$``@`"``$`!0`"``,`
M`0`!``$``0`!``$``@`"``$``@`"``(``0`"``(``0`&``(``@`%``(``0`!
M``(``@`#``(``@`!``$`!P`(``(``@`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``@`"``$``0`!``$``0`"``$``@`!``$``0`!``$`!P#E
M`@``$`````````"4D98&```(`!\$```0````M)&6!@``!P`J!```$````!1I
M:0T```8`-00``!````"SD98&```%`#\$```0````<AEI"0``!`!*!```$```
M`'09:0D```,`5@0``!````!U&FD)```"`&($````````Z+L````````(````
M`````(`F````````\+L````````(`````````$`F````````",`````````(
M``````````C`````````(,`````````(`````````/AB````````N+\`````
M```&````!@``````````````P+\````````&````!P``````````````R+\`
M```````&````%```````````````T+\````````&````&```````````````
MV+\````````&````6```````````````X+\````````2````'0``````````
M````Z+\````````&````'@``````````````\+\````````&````'P``````
M````````^+\````````&````.@``````````````0,`````````%````3P``
M````````````8,`````````%````4```````````````<,`````````%````
M6P``````````````$+X````````'`````0``````````````&+X````````'
M`````@``````````````(+X````````'`````P``````````````*+X`````
M```'````!```````````````,+X````````'````!0``````````````.+X`
M```````'````"```````````````0+X````````'````"0``````````````
M2+X````````'````"@``````````````4+X````````'````"P``````````
M````6+X````````'````#```````````````8+X````````'````#0``````
M````````:+X````````'````#@``````````````<+X````````'````#P``
M````````````>+X````````'````$```````````````@+X````````'````
M$0``````````````B+X````````'````$@``````````````D+X````````'
M````$P``````````````F+X````````'````%0``````````````H+X`````
M```'````%@``````````````J+X````````'````%P``````````````L+X`
M```````'````&0``````````````N+X````````'````&@``````````````
MP+X````````'````&P``````````````R+X````````'````'```````````
M````T+X````````'````(```````````````V+X````````'````(0``````
M````````X+X````````'````(@``````````````Z+X````````'````(P``
M````````````\+X````````'````)```````````````^+X````````'````
M)0```````````````+\````````'````)@``````````````"+\````````'
M````)P``````````````$+\````````'````*```````````````&+\`````
M```'````*0``````````````(+\````````'````*@``````````````*+\`
M```````'````*P``````````````,+\````````'````+```````````````
M.+\````````'````+0``````````````0+\````````'````+@``````````
M````2+\````````'````+P``````````````4+\````````'````,```````
M````````6+\````````'````,0``````````````8+\````````'````,@``
M````````````:+\````````'````,P``````````````<+\````````'````
M-```````````````>+\````````'````-0``````````````@+\````````'
M````-@``````````````B+\````````'````-P``````````````D+\`````
M```'````.```````````````F+\````````'````.0``````````````H+\`
M```````'````.P``````````````J+\````````'````/```````````````
ML+\````````'````/0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%M9\``$B%P'0"_]!(@\0(PP```````````/\UVIT``/\EW)T`
M``\?0`#_)=J=``!H`````.G@_____R72G0``:`$```#IT/____\ERIT``&@"
M````Z<#_____)<*=``!H`P```.FP_____R6ZG0``:`0```#IH/____\ELIT`
M`&@%````Z9#_____):J=``!H!@```.F`_____R6BG0``:`<```#I</____\E
MFIT``&@(````Z6#_____)9*=``!H"0```.E0_____R6*G0``:`H```#I0/__
M__\E@IT``&@+````Z3#_____)7J=``!H#````.D@_____R5RG0``:`T```#I
M$/____\E:IT``&@.````Z0#_____)6*=``!H#P```.GP_O___R5:G0``:!``
M``#IX/[___\E4IT``&@1````Z=#^____)4J=``!H$@```.G`_O___R5"G0``
M:!,```#IL/[___\E.IT``&@4````Z:#^____)3*=``!H%0```.F0_O___R4J
MG0``:!8```#I@/[___\E(IT``&@7````Z7#^____)1J=``!H&````.E@_O__
M_R42G0``:!D```#I4/[___\E"IT``&@:````Z4#^____)0*=``!H&P```.DP
M_O___R7ZG```:!P```#I(/[___\E\IP``&@=````Z1#^____)>J<``!H'@``
M`.D`_O___R7BG```:!\```#I\/W___\EVIP``&@@````Z>#]____)=*<``!H
M(0```.G0_?___R7*G```:"(```#IP/W___\EPIP``&@C````Z;#]____);J<
M``!H)````.F@_?___R6RG```:"4```#ID/W___\EJIP``&@F````Z8#]____
M):*<``!H)P```.EP_?___R6:G```:"@```#I8/W___\EDIP``&@I````Z5#]
M____)8J<``!H*@```.E`_?___R6"G```:"L```#I,/W___\E>IP``&@L````
MZ2#]____)7*<``!H+0```.D0_?___R5JG```:"X```#I`/W___\E8IP``&@O
M````Z?#\____)5J<``!H,````.G@_/___R52G```:#$```#IT/S___\E2IP`
M`&@R````Z<#\____)4*<``!H,P```.FP_/___R4ZG```:#0```#IH/S___\E
M4IP``&:0``````````#S#Q[Z55-(@^PXB7PD'$B-?"0<2(ET)!!(C70D$$B)
M5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z'3___](BS7EFP``2(L]%IP``$B)
M\NA>.@``@#V'G`````^$&0$``$B+!>J;``!D2(L`@(@Z!````XM$)!R->`2-
M6`-(8_](P><#Z+G^__](BWPD$$2+1"0<2(G!2(D%79P``$B+!TB)`4B-!:\]
M``!(B4$(2(L%W9L``$B)01!(C06</0``2(E!&$&#^`$/CB<!``!(@\<(08/`
M`[H$````#Q^``````$B+!TAC\H/"`4B#QPA(B03Q1#G"=>I(8])(BST`G```
M13'`2(TUY@<``$C'!-$`````B=KHI_O__X7`#X2'````2(L]V)L``$B-;"0D
MZ&[]__](B>Y(C3W7.P``B<,QP.B[`0``2(7`=&](BSVOFP``Z$K[___HM?S_
M_TB+1"0H9$@K!"4H````#X68````2(/$.(G86UW#Z#/\__](B05\FP``2(G'
M2(7`=''HG_S__TB+!;B:``!D2(L0QH(N"0```.F^_O__2(L]49L``.B,^___
MZ6C___](BSTPFP``2(7_=`KH1AT``.E[____2(T]\CH``$B)[N@B`0``2(D%
M"YL``$B)QTB%P`^$6?___^O2N@0```#I^?[__[\!````Z.GZ___HU/S__P\?
M0``Q[4F)T5Y(B>)(@^3P4%1%,<`QR4B-/=7]____%3>:``#T9BX/'X0`````
M``\?0`!(C3U1F@``2(T%2IH``$@Y^'052(L%WID``$B%P'0)_^`/'X``````
MPP\?@`````!(C3TAF@``2(TU&IH``$@I_DB)\$C![C](P?@#2`'&2-'^=!1(
MBP6EF0``2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`])IH```!U*U5(@SV"
MF0```$B)Y70,2(L]IID``.@9_?__Z&3____&!?Z9```!7<,/'P###Q^`````
M`/,/'OKI=____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R+-9*9
M``!-A?8/A*$````/M@=)B?])B?6$P'0$/#UU6$4QY$F+'DB%VW0S36/D3(GU
M#Q^``````$R)XDR)_DB)W^C"^?__A<!U!T*`/",]=$=(BUT(2(/%"$B%VW7:
M2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)@\0!A,!T!#P]
M=>Y%*?SKD68/'T0``$PI]4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/'T``
M4TB)^TB![*````!D2(L$)2@```!(B80DF````#'`2(GFZ!K[__^%P'4VBU0D
M&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^A?^___A<`/E,`/ML#K
M!P\?1```,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#Z(WZ__]F9BX/
M'X0``````&:0055!5%532('LJ````&1(BP0E*````$B)A"28````,<!(A?]T
M"(`_`$B)^W4K2(N$))@```!D2"L$)2@````/A2,!``!(@<2H````6UU!7$%=
MPV8/'T0``.@S^?__2(G%2(7`=,A(B>_H`_O__TB%P`^$L@```(!X$RY,C6`3
M=1!!@'PD`0!TW0\?A```````@'@3+@^$I@```$B)W^C.^/__3(GG28G%Z,/X
M__]!C7P%`DAC_^@6^/__38GA28G8O@$```!)B<5(B<<QP$C'PO____](C0TY
M-P``Z##Z__],B>](B>;HE?C__TR)[X/X_W00BT0D&"4`\```/0!```!T7>CX
M]___3(GOZ%#X__](B>_H6/K__TB%P`^%5?___P\?@`````!(B>_HT/G__TB)
MW^C8]___Z?#^__\/'P!!@'PD`2X/A4[___]!@'PD`@`/A`W____I/?___P\?
M`.B;_O__ZZ'H%/G__P\?0`!!5T%6055!5%5(B?532(G[2(/L&&1(BP0E*```
M`$B)1"0(,<`QP(`^/0^4P$@!Q4B)[^C)]___2(UT)`1(B=])B<0QP.CG_/__
M2(7`#X0&`0``2(G'28G%Z*/W__],.>`/@](```!,8W0D!$G!Y@,/M@.$P`^$
MG@$``#P]#X26`0``2(G8#Q\`#[90`4B#P`&$TG0%@/H]=>](*=A(F$R++3N6
M``!*C7P@`NBQ]O__30'U28E%`$B%P'162(L%'I8``$B-2P%*BQ0P#[8#B`(\
M/70BA,!U#>L<#Q^``````#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`9@\?
M1```#[9,!0"(3`(!2(/``83)=>](BT0D"&1(*P0E*`````^%!P$``$B#Q!A;
M74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`08A4!0!(@\`!A-)U[NN]#Q]`
M`$R+/8&5``!)@S\`#X2V````3(GX13'MD$B#P`A$B>I!@\4!2(,X`'7OC7(#
M2&/V2,'F`XL%AY4``(7`=5O'!7F5```!````2(GWZ+GU__](A<`/A&'___]-
M8_5,B?Y(B<=)P>8#3(GRZ.OV__](B044E0``2(G!08U%`42);"0$2)A(QP3!
M`````.F(_O__9@\?A```````3(G_Z,CW__](B07AE```2(G!2(7`#X0&____
M36/U2<'F`^N[#Q]``#'`Z7_^__^^$````$4Q[>E?____Z-_V__]F9BX/'X0`
M``````\?0`!!54%455-(@>P`$```2(,,)`!(@^P8NO\/``!D2(L$)2@```!(
MB80D"!```#'`28GD2(G[2(GU2(T]+#0``$R)YN@:]O__A<!^$HG!@^@!2&/0
M@#P4`'5(A<!U/$B+!=V3``!(B>I(B=YD2(LXZ/[T__](BX0D"!```&1(*P0E
M*````'5.2('$&!```%M=05Q!7<,/'T0``(G!9@\?1```3&/IOB\```!,B>=,
MB>KH#?3__TB%P'2D2(L%@9,``$R)Z4R)XDB)WF1(BSCH?_7__^N?Z/CU__\/
M'X0``````/,/'OI32(L=5),``$B-#=US``!(C35_,P``2(L51Y,``&1(BSOH
MAO;__V1(BSM%,<E;3(T%"S4``$B-%<`3``!,B<%(C35K,P``Z>'T__^0\P\>
M^DB+!063``!(BQ4&DP``2(T-AW,``$B--2DS``!D2(LXZ3?V__\/'X``````
M\P\>^E532('L`!```$B##"0`2('L`!```$B##"0`2(/L*&1(BP0E*````$B)
MA"08(```,<!(B>-(C:PD$!```.C;\___2(T-_C(``+H!$```2(G?08G`3(T-
MMS(``+X!````,<#HEO7__[H`$```2(GN2(G?Z(;T__\QR87`>"Z->`%(B<-(
M8__H,O/__TB)P4B%P'082&/;2(GN2(G'2(G:Z*GU___&!!@`2(G!2(N$)!@@
M``!D2"L$)2@```!U#4B!Q"@@``!(B<A;7</HG?3__V9F+@\?A```````9I#S
M#Q[ZZ1?___\/'X``````\P\>^D%7059!54%455-(@>P`$```2(,,)`!(@>RX
M````9$B+!"4H````2(F$)*@0```QP$F)_$B)\TB-/2<R``!(C70D#.A5^/__
MOB\```!,B>=(B<7HU?/__TB%P'1`,<!,B>9(C3T%,@``Z/_Z__],B>!(BY0D
MJ!```&1(*Q0E*`````^%@@$``$B!Q+@0``!;74%<05U!7D%?PP\?`$B)WTR-
M+=0Q``!,C373,@``Z*KS__],B>Y(B<?HW_/__TB)PTB%P'27@#L`#X3D````
M9@\?1```2(7M=!-(B=Y(B>_HJ//__X7`#X2G````2(G?Z'CR__](C50#_TF)
MQT@YTW(7ZR5F#Q^$``````#&`@!(@^H!2#G3=`6`.B]T[TB)W^A'\O__28G'
M3(GGZ#SR__])C40'`4@]_P\```^'&____TR-O"2@````3(GQ28G8,<!(@^P(
MN@`0``"^`0```$R)_T%43(T-$3$``.B<\___2(UT)"!,B?_H__'__UI9A<!U
M$(M$)"@E`/```#T`@```=$E,B>XQ_^C_\O__2(G#2(7`#X2S_O__@#L`#X4B
M____2(7M=`:`?0`N=!=!OP$```!(C1V8,```Z5G___\/'T0``(!]`0!TN>OA
MO@$```!,B?_H,_/__X7`=:9,B?Y(C3UV,```Z'#Y__],B?_H6/+__^EG_O__
MZ&[R__]F9BX/'X0```````\?`/,/'OI3OB\```!(B?OHKO'__TB-4`%(A<!(
M#T7:2(G?6^D:\O__9BX/'X0``````/,/'OI54TB![``0``!(@PPD`$B#[!AD
M2(L$)2@```!(B80D"!```#'`2(7_#X3.````@#\`2(G[#X3"````Z-WP__](
MC5`!2('Z`!````^'Y````$B)Y4B)[X/Z"'(.B=%(B=[!Z0/S2*5(B?,QR?;"
M!'0)BPN)#[D$````]L("=`Y$#[<$"V9$B00/2(/!`H/B`70'#[84"X@4#TB-
M1`7_2#G%<A;K&0\?A```````Q@``2(/H`4@YZ'0%@#@O=.^^+P```$B)[^C"
M\/__2(7`="U(.<5R6$B)[^@P\?__2(N4)`@0``!D2"L4)2@```!U24B!Q!@0
M``!;7<,/'P!(BX0D"!```&1(*P0E*````'4I2('$&!```$B-/?4N``!;7>GH
M\/__#Q^$``````#&``#KHP\?`#'`ZZ3H[_#__V9F+@\?A```````#Q]``/,/
M'OI!5T%6055!5%5(C2W.+@``4TB#[!AD2(L$)2@```!(B40D"#'`2(U<)`1F
MD#'`2(G>2(GOZ,/T__](A<!T-DAC5"0$2(L%8HX``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+6PN``"0,<!(B=Y(B>_H
M<_3__TB%P'0V2&-4)`1(BP42C@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```2(TM)"X``)`QP$B)WDB)[^@C]/__2(7`=#9(
M8U0D!$B+!<*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7P
MZ[YF#Q]$``!(C2W=+0``D#'`2(G>2(GOZ-/S__](A<!T-DAC5"0$2(L%<HT`
M`$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-
M+90M``"0,<!(B=Y(B>_H@_/__TB%P'0V2&-4)`1(BP4BC0``2(T$T$B+4`A(
MB1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE5"T``)`QP$B)
MWDR)Y^@S\___2(7`=#9(8U0D!$B+!=*,``!(C0302(M0"$B)$$B%TG329I!(
MBU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C26Y+```D#'`2(G>3(GGZ./R__](
MA<!T-DAC5"0$2(L%@HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D0
M2(72=?#KOF8/'T0``$R--<`L``"0,<!(B=Y,B??HD_+__TB%P'0V2&-4)`1(
MBP4RC```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?
M1```3(TM>BP``)`QP$B)WDR)[^A#\O__2(7`=#9(8U0D!$B+!>*+``!(C030
M2(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C3TT+```
MD#'`2(G>3(G_Z//Q__](A<!T-DAC5"0$2(L%DHL``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/8(K``"0,<!(B=Y,B?_H
MH_'__TB%P'0V2&-4)`1(BP5"BP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```2(G>2(T]FRL``.A9\?__2(7`=`U(B<9,B>\Q
MP.@7]/__,<!(B=Y(C3V)*P``Z#;Q__](A<!T$4B)QDB-/8<K```QP.CP\___
M2(G>2(T]@2L``#'`Z`_Q__](B<9(A<!T.4R)YS'`Z,WS__](BT0D"&1(*P0E
M*````'5$2(/$&$B)[TB--6LK```QP%M=05Q!74%>05_IGO/__S'`2(G>2(T]
M/2L``.B]\/__2(7`=+M(B<9,B?<QP.A[\___ZZSHA.S__P\?0`#S#Q[Z2(/L
M&$B-/;`J``!D2(L$)2@```!(B40D"#'`2(UT)`3H=_#__TB%P'0R#[80@/HP
M#Y3`A-(/E,()T(/P`0^VP$B+5"0(9$@K%"4H````=1!(@\08PP\?@``````Q
MP.O@Z!?L__\/'X``````\P\>^E!82('LV````$B)="0H2(E4)#!(B4PD.$R)
M1"1`3(E,)$B$P'0W#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD`````\I
MK"2@````#RFT)+`````/*;PDP````&1(BP0E*````$B)1"08,<!(B?I(C80D
MX````$B)X4B+/7J)``!(B40D"+X!````2(U$)"#'!"0(````QT0D!#````!(
MB40D$.B"ZO__O_\```#H:.G__P\?A```````05154TR-G"0``/__2('L`!``
M`$B##"0`3#G<=>](@^P0N@(````Q]F1(BP0E*````$B)A"0(``$`,<!!B?Q(
MB>/H>NO__TB-:/](B>I(P?H_2,'J,$B-1!4`#[?`2"G02"G%#XBK````#Q^`
M`````#'22(GN1(GGZ$/K__](@_C_#X2D````N@@``0!(B=Y$B>?HZ>C__X/X
M_P^$?0```$B82(/X!W982(U$`_A(.=AR3DB-%3>(``#K#@\?1```2(/H`4@Y
MV'(W2(L*2#D(=>](*=A(`>A(BY0D"``!`&1(*Q0E*````'5/2('$$``!`%M=
M05S#9BX/'X0``````$B![0```0!(@?T``/__#X5<____2,?`_____^NZ2(T]
MYR@``#'`Z!7^__](C3W,*```,<#H!_[__^@2ZO__9I#S#Q[Z2(/L".A#ZO__
MB<?HO.C__TB%P'0#2(L`2(/$",-F9BX/'X0```````\?0`#S#Q[Z055!5$R-
M)9@H``!52(G]3(GG4TB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3HR^W__TB%
MP'0(@#@`2(G#=2Y(BT0D"&1(*P0E*`````^%?0```$B)[DB#Q!A,B><QP%M=
M05Q!7>EC\/__#Q\`2(GOZ%CH__](B=])B<7H3>C__TF-?`4"Z*/G__](@^P(
M28GHO@$```!32,?"_____TB)QTF)Q4R-#3`G``!(C0TO*```,<#HM.G__UA:
M2(M$)`AD2"L$)2@```!U!4R)[NN&Z`CI__\/'X0``````/,/'OI!5TB-%=$G
M``!(C0UE)P``059F2`]NPDB-%70G``!)B?Y!54B-/;HF``!!5%532('L>`$`
M`&1(BP0E*````$B)A"1H`0``2(T%E28``$B-;"0<2,=$)#``````2,>$)(@`
M````````2(GN2,=$)%``````9D@/;LA(C05@)P``9@]LP69(#V[02(T%6"<`
M``\I1"0@9D@/;L%F2`]NV$B-#48G``!F#VS"2(T%0"<```\11"1H9D@/;L)F
M2`]NX#'`9@]LPP\11"1X9D@/;L%F#VS$#RE$)$#H/^S__TB%P'0,@#@`2(G#
M#X66!```Z$GH__^)Q^C"YO__2(7`#X3I`P``3(L@387D#X3=`P``3(GGZ-7F
M__](C7P``>@KYO__10^V!"1)B<=(B<-%A,!T.DR-+<$F```/'T``10^VP$R)
M_TR)Z;X!````2,?"_____S'`28/$`4F#QP+H*^C__T4/M@0D183`==%,C6PD
M8$B-/04F``#K$`\?`$F+?0A)@\4(2(7_=#-(B>XQP.B)Z___28G$2(7`=.&`
M.`!TW$B)Q^A$[/__A<!TT$R)Y^@HY___28G'2(7`=4!,C60D($V+/"1-A?]T
M,D&`/P`/A`@#``!,B?_H$.S__X7`#X4``0``38M\)`A)@\0(387_==AF+@\?
MA```````3(G_Z.CE__](B=])B<3HW>7__T6-I`0$!```36/D3(GGZ"KE__]3
M38GX3(T-SR0``$F)Q4B-!=`E``"^`0```$C'PO____]02(T-LR4``$R)[S'`
MZ#?G__],B>^^P`$``.B:Y___7T%8@_C_=1+H7>;__T2+"$&#^1$/A=T"``!(
MC;0DD````$R)[^B@YO__B<.%P'1R28L.2(L]4(0``$V)Z#'`2(T5%"8``+X!
M````Z$KD__]%,>1(BX0D:`$``&1(*P0E*`````^%'@0``$B!Q'@!``!,B>!;
M74%<05U!7D%?PP\?`$R)_TF#Q`CH[.7__TF)QTB%P`^$Q?[__^G[_O__#Q\`
MBX0DJ````"4`\```/0!````/A7?___]$B[PDK````.@4YO__03G'#X5A____
MBX0DJ````"7_`0``/<`!```/A4K___],B>?H_./__TB)[DB-/70D``!)B<0Q
MP.BXZ?__2(7`#X1/`@``28L^2(G&Z`3Q__])B<=(A<`/A#@"``!,B?_H8.3_
M_TB)PH/X`WY`2)A(C35O)```2(E4)`A)C7P'_.A@Y?__A<!U)$B+5"0(@_H$
M#X3Q`@``C4+[2)A!@#P'+P^$X0(``&8/'T0``$B)[DB-+5TC```QP$B)[^@T
MZ?__2(7`#X3;`0``#[8`A,`/A-`!```\,`^$R`$``$B)[TB--9HC```QP.C7
MZ___2(TM-"0``$R--1LD``#HA./__U5(Q\+_____38GH4$R-#<$B``"^`0``
M`$R)YTB-#>8C```QP.@[Y?__6%KK1P\?@`````#H:^3__X,X$75(Z$'C__^#
MPP%(@^P(38GH54R-#7\B``!,B?&^`0```%-(Q\+_____3(GG4#'`Z/3D__](
M@\0@OL`!``!,B>?H4^7__X/X_W2N3(GOZ";C__],B>9(C3TD(@``,<#H)>O_
M_TR)Y^A-^O__Z>']__\/'X0``````$4Q_^D8_?__#Q^$``````!(BWPD0$B-
M7"1`2(7_="*0,<!(B>[H%NC__TB%P'0%@#@`=31(BWL(2(/#"$B%_W7?OPT`
M``!,C26J(@``Z![B__]!N%,```!)B<=(B</I\OO__P\?1```2(G'Z)#C__])
MB<1(A<!TO.FV^___28L.2(L]B8$``$V)Z#'`2(T5#2,``+X!````Z(/A___I
M-/W__V8/'T0``$B)Q^B0^?__2(N$)&@!``!D2"L$)2@````/A4<!``!(@<1X
M`0``2(G?6UU!7$%=05Y!7^D@X___38L^Z<#]__\/'X0``````#'V3(G_,<#H
ME.+__T&)QH7`#X0A_O__B<?HPO?__TF)QTB%P`^(#O[__S'22(UP]D2)]^AH
MX___2(VT)"H!``"Z!@```$2)]^@3X?__2(/X!@^%S````(&\)"H!````0T%#
M#X70_?__9H&\)"X!``!(10^%P/W__S'228UWSD2)]^@:X___2(V<)#`!``"Z
M*````$2)]TB)WNC"X/__2(/X*'5_2(T%V2$``+X!````38GH3(GGQH0D6`$`
M``!(C0V0(0``3(T-9"```$C'PO____]0,<!3Z.3B__]97NG__?__38MV"$V%
M]@^$&/W__TR)]^@HX?__2(/X`P^&!OW__TF-?`;\2(TU-R$``.@MXO__A<!-
M#T3^Z>K\___H#>+__TB-/2`A```QP.CO]?__9F8N#Q^$```````/'T``\P\>
M^D%42(T]!B```%532(/L$$B+'49_``!D2(L$)2@```!(B40D"#'`3(UD)`1,
MB>9D2(LK#[:%L````(B%L0```#'`Z,;E__](A<!T"8`X,0^$:`$``#'`Z+'P
M__]D2(LK2(GON0,```"Z`0```$B--<P@``#HY-___TB)Q4B%P'0H2(M`$&1(
MBSM(C16R(```2(LPZ/7?__](BT402(LP]D8.0`^%1`$``&1(BSNY`P```+H!
M````2(TUB2```.B:W___2(G%2(7`="U,B>9(C3T)'P``,<#H,>7__TB)PDB%
MP`^$Y0```$B+11!D2(L[2(LPZ)7?__]D2(L[N@$```!(C35!(```Z+#>__]D
M2(L[2(T51B```$B)QNAMW___9$B+`TR)YDB-/:<>``#&@+$`````,<#HT>3_
M_TB)!;I^``!(B<-(A<!T0K[``0``2(G?Z)7A__^-4`&#^@%V"8/X$0^%D@``
M`$B+1"0(9$@K!"4H````#X6;````2(/$$%M=05S##Q^``````$B+/7%^``#H
M5/?__TB)!5U^``!(B<-(A<!UHTB-/58@```QP.B'X/__#Q^``````(!X`0`/
MA)G^___IB?[__Y!(BP4Q?@``2(LP2(M%$$B+..@ZZ?__Z1#___\/'T0``&1(
MBSOHY]___^FN_O__B<%(BP4!?@``2(G:2(T]'R```$B+,#'`Z"7@___HT-__
M__,/'OI54TB)^TB-/?\=``!(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z,+C
M__](A<!T'`^V$(#Z,`^4P(32#Y3""-!U"DB%VW0%@#L`=2%(BT0D"&1(*P0E
M*````'5R2(/$&%M=PV8N#Q^$``````!(B=_H*.W__[XO````2(G'2(G%Z*C>
M__](C5`!2(7`2`]%ZDB)[^@5W___N@0```!(C34T'@``2(G'Z&'=__^%P'6<
M2(M$)`AD2"L$)2@```!U#DB#Q!A(B=];7>E_Y/__Z/K>__]F+@\?A```````
M05=(B?Y,C4<X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)
MXDR-C"2`````2(G7#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,
MB=!(P>D@2,'H*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G0
M2`G(2(E'^$PYSW6M9@]O3"009@]O7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O
M+4=<```/'X``````\P]O`&8/;^)F#V]0V$B#P!!F#^](B&8/[\)F#^_!9@]O
MR&8/<]`?9@]S\0%F#^O!9@]ORV8/;]QF#]O%#RE`"$@YT'6[3(L.3(M>$$B+
M?B!(BUX83(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4
M.)EY@EI,B=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!
MZAM!B=!,,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I
M`DC!X!Y/C903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-
M">I,BVPD&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPA
MX$G![1M(,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-
MC"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD
M*`'13(G22<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQ
MX$@!^$B)STC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`
M28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!
MZ0)(P>(>18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))
MP>(%30GJ3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"
M2<'M&XG'3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%
MB<!*C8PIF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI
M3(ML)%`!P4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),
M(<),,>)(`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"
M6DP)PDF)_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(
MB<A(P>`>2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'2
M38GB2<'B!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)
MU4@QT$G![1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(
MP>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A
M!4P)Z4R+;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;
M08G23"'`3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_
M3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-
M+")(B<I(P>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%(
M(?A,,<!,`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-
MA""9>8):2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!
MPDV)Z$G![0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q
M^$G![1M(`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)
MP$DQRD0QTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG2
M2`'73(GB2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$
M,>!-C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)
MX$P)Z$F)U8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%
M2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0D
MP````(G)23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`
MB<!)`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0Y
MH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)
MPHG`2`.$)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))
M`=5,B<))P>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9
M;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG2
M2`.4).@```!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,
MB=%)P>H"2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)
M^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'0
M13'H3HVL`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(
MP>\"2,'@'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)
MQTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!
M``!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"
M2,'B'D6)ZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)
MP$@#C"00`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(
M,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A
M'D2)[TP)T4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(
MP>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'K
MV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$`
M`$@)^$B)UXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%
M3`GG38G42<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)
M_4Z-E!*AZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)
MX$6)Y$DQT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!
M2(GY2,'O`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),
M`>)-B<1,`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G1
M28G608G222'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E
M!4T)]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT
M)%`!``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)
M_TP)XD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ
M2<'N&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPA
MZDP)\DR+M"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(
MP>\"2,'B'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-
MB<9,`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*
M20G.32'&3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)
M]4$!U4R)PDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!
M``!)`<9,`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)
M_TP)X4&)S$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N
M&TG!X@5-"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)
M\4R+M"2(`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(
MP>\"2,'A'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,
M`>)-B<1)P>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G2
M22'^3"'!3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)
MUD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)
M`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)
MT4F)UD&)U$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!
MX@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+
MM"2P`0``20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B
M'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-
MB<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&
M3"'23`GR3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)
MPDG!Z`)(P>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,
M`<=-B>A(`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)
M_$@)^4PAZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)
MP>H;2,'A!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-
M(>5)"?U*C3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`
M2<'H`DC!X!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,
MB>E)P>P;2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQ
MU$0QYTR+I"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"
M2<'F'D6)Y$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'0
M3(GB2<'N&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'2
M3`'Y3(N\)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA
M2<'L`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(
M3(G12<'M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"
M``!)`<9,`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G2
M2<'J`DC!XAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'0
M3(GR2<'L&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"
M``!)`<5,`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ
M2<'N`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(
M3(GI2<'J&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"
M``!)`<1,`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ
M2<'M`DC!XAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'0
M3(GB2<'N&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)
M`<),`=%-B>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA
M2<'L`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(
M3(G12<'M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)
M`<9,`?)-B>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G2
M2<'J`DC!XAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP
M20'43(GR2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"
M``!)`<5,`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ
M2<'N`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'1
M38GJ2<'L&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``
M08G*20'$2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B
M!4P)XDV)[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)
MUDP!P$V)Z$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQ
MT$0QQTF)R$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)
M!DB)T$C!Z@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'42
M2('$F`(``%M=05Q!74%>05_#Z(;(__]F#Q]$``#S#Q[Z2(/L"+^`````Z+[&
M__]F#V\%AD8``$C'0#``````#Q$`9@]O!8-&``#'0'@`````#Q%`$&8/;P6`
M1@``#Q%`($B#Q`C##Q^``````/,/'OI!5TACPD%628G&055!5$F)_%5(C6\X
M4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=X
MA<`/A>D```!!@_X_#XXG`0``08/N0$6)]T'![P9%C6\!2<'E!DD!W9#S#V\#
M3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HH>C__TPY
MZW7,0<'G!D4I_DECQDB#^`AR7$F+50!)C4PD0$B#X?A)B50D.$F+5`7X2(E4
M!?A(*<U(`>A)*>U(@^#X2(/X"'(82(/@^#'228MT%0!(B3012(/""$@YPG+N
M18ET)'A(@\0(6UU!7$%=05Y!7\.0J`1U=$B%P'3B00^V50!!B%0D.*@"=-1!
M#[=4!?YFB50%_NO'#Q]``$&_0````$B-?`4`2(G>02G'13GW10]/_DUC[TR)
MZNBUQ___08M$)'A$`?A!B40D>(/X0'633(GG12G^3`'KZ,7G___IS_[__TF)
MW>DC____08M5`$&)5"0X08M4!?R)5`7\Z5S___^0\P\>^D%63(UV.$%50515
M2(G]4TR+;BA(B?-,BV8P3(GH2,'H`X/@/XU0`<9$!CB`2&/*@_HX#XZ$`0``
MOD````!,`?$IUG0/,<")PH/``<8$$0`Y\'+S2(G?Z$'G__]F#^_`#Q%#.$G'
M1C``````00\11A!!#Q%&($R)XD$/ML5,B>],B>Y(P>H82,'@"$R)X4C![Q!)
MB=!,B>I(P>X8#[;60`^V_T`/MO9(P>D02`G03(GB#[;)2,'@"$@)^`^V_D$/
MMM!(P>`(2`GP00^V]$C!X`A("?!(P>`(2`GX2(G?2,'@"$@)R$C!X`A("=!(
MB4-PZ*CF__](BP-(B=](P>@8B$4`2(L#2,'H$(A%`4B+`XAE`DB+`XA%`TB+
M0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#"(A%!TB+0Q!(P>@8B$4(
M2(M#$$C!Z!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(P>@8B$4,2(M#&$C!Z!"(
M10U(BT,8B&4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(11%(BT,@B&42
M2(M#((A%$UM=05Q!74%>Z;C#__\/'X0``````+@X````20'.,?\IT(/X"')'
M28U."(G"2<<&`````$G'1!;X`````$B#X?A)*<Y$`?"#X/B#^`@/@GS^__^#
MX/@QTHG6@\((2(D\,3G"<O/I9?[__P\?0`"H!'4DA<`/A%7^__]!Q@8`J`(/
MA$G^__\QTF9!B50&_ND\_O__#Q\`0<<&`````$''1`;\`````.DD_O__9BX/
M'X0``````)!(BPW!80``Z43"__](@^P(2(/$",,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````_____P````#_____``````$C16<`````B:O-[P````#^W+J8`````'94
M,A``````\.'2PP````````````````$;`SO\````'@```&!___](`0``P(+_
M_W`!``#0@O__-`8``."$__\8`0``T(7__X@!``"@AO__U`$``#"'___X`0``
MH(C__S0"``#@BO__@`(``,"+___``@``$(S__]P"``!`C/__\`(``""-__\D
M`P``,(W__S@#``!0C___G`,``("/__^X`P``T)#___0#```PE?__0`0``*"5
M__]<!```8);__W@$``"@E___N`0``-"7___0!```L)C__Q@%``#`G___R`4`
M`."A___\!0``P*+__V`&```PN?__L`8``("Y___(!@``(+O__Q0'``"`O?__
M6`<````````4``````````%Z4@`!>!`!&PP'")`!!Q`4````'````,"#__\B
M```````````````4``````````%Z4@`!>!`!&PP'")`!```D````'````!!^
M__]@`P````X01@X82@\+=PB``#\:.RHS)"(`````%````$0```!(@?__"```
M````````````2````%P```!`A/__S`````!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"````"H
M````Q(3__X,`````00X0@P)*#K`!`G$*#A!!#@A!"S@```#,````,(7__VP!
M````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.$$(."$<+
M`$@````(`0``9(;__S$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0.
M.(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L\````5`$``%B(___8
M`````$(.$(T"0@X8C`-!#B"&!$$.*(,%1PZH($D.P"`"=@H.*$$.($$.&$(.
M$$(."$8+&````)0!``#XB/__3P````!%#A"#`FT."````!````"P`0``+(G_
M_RD`````````,````,0!``!(B?__TP````!%#A"&`D$.&(,#1PZ8($P.F$!)
M#L!``J8*#AA$#A!!#@A!"Q````#X`0``](G__PD`````````8`````P"``#P
MB?__$@(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`[P
M(0)Q"@XX00XP00XH0@X@0@X80@X00@X(1`L"N0[X(4\.@"):#O@A00[P(0``
M`!@```!P`@``K(O__R8`````10X0@P)<#@@````X````C`(``,"+__]!`0``
M`$4.$(8"00X8@P-'#I@@20ZP(`+D"@X800X000X(1`M:"@X82`X000X(30M(
M````R`(``-2,__]<!````$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#
M!T0.4`/^`PH..$T.,$$.*$(.($(.&$(.$$(."$4+&````!0#``#HD/__:0``
M``!(#B`"4`H."$@+`!@````P`P``/)'__[@`````10X000X(1P[@`0`\````
M3`,``."1__\^`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-!T0.L(`$`M`*
M#B!!#AA!#A!"#@A+"P``%````(P#``#@DO__(0````!(#A!8#@@`1````*0#
M``#XDO__V`````!&#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)""@XH1@X@00X8
M0@X00@X(2`MA#DA)#E!C#DA!#D``K````.P#``"0D___`0<```!&#A"/`E`.
M&(X#40X@C01)#BB,!4$.,(8&00XX@P='#K`#`^X!#K@#80[``U\.N`-"#K`#
M`FX*#CA$#C!!#BA"#B!"#AA"#A!"#@A$"P-%`0ZX`TL.P`->#K@#00ZP`U\.
MN`-$#L`#4`[(`TL.T`-+#K`#`PX!"@XX1`XP00XH0@X@0@X80@X00@X(10L"
MY`ZX`T,.P`-&#K@#00ZP`P`P````G`0``/"9__\@`@```$8.$(P"2`X8A@-!
M#B"#!$0.,`-Q`0H.($$.&$$.$$(."$@+-````-`$``#<F___U@````!%#A"&
M`D$.&(,#3@XP`D\*#AA!#A!!#@A+"P)7"@X81`X000X(10LH````"`4``)1\
M__\,`@```$4.$(8"00X8@P-$#E`#:0$*#AA##A!!#@A!"TP````T!0``6)S_
M_VH6````0@X0CP))#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0-"%@H.
M.$$.,$$.*$(.($(.&$(.$$(."$$+````%````(0%``!XLO__20````!(#A`"
M0`X(2````)P%``"PLO__GP$```!&#A"/`D4.&(X#10X@C01"#BB,!40.,(8&
M10XX@P='#D`"X@H..$$.,$$.*$(.($(.&$(.$$(."$(+`$````#H!0``!+3_
M_U4"````1@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@.9`0H.*$$.($(.&$(.
M$$(."$T+````````$````"P&```@MO__#```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(`F
M````````0"8````````!`````````-4"`````````0````````#E`@``````
M``P``````````"`````````-`````````$Q>````````&0````````#HNP``
M`````!L`````````"``````````:`````````/"[````````'``````````(
M`````````/7^_V\`````H`,````````%`````````$@-````````!@``````
M``"0!`````````H`````````;@0````````+`````````!@`````````%0``
M``````````````````,`````````^+T````````"`````````/@$````````
M%``````````'`````````!<`````````<!0````````'`````````/`2````
M````"`````````"``0````````D`````````&``````````>``````````@`
M````````^___;P`````!```(`````/[__V\`````<!(```````#___]O````
M``$`````````\/__;P````"V$0```````/G__V\`````!```````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````/B[````````````````
M`````````````#8@````````1B````````!6(````````&8@````````=B``
M``````"&(````````)8@````````IB````````"V(````````,8@````````
MUB````````#F(````````/8@````````!B$````````6(0```````"8A````
M````-B$```````!&(0```````%8A````````9B$```````!V(0```````(8A
M````````EB$```````"F(0```````+8A````````QB$```````#6(0``````
M`.8A````````]B$````````&(@```````!8B````````)B(````````V(@``
M`````$8B````````5B(```````!F(@```````'8B````````AB(```````"6
M(@```````*8B````````MB(```````#&(@```````-8B````````YB(`````
M``#V(@````````8C````````%B,````````F(P```````#8C````````1B,`
M``````!6(P```````&8C````````=B,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````/AB
M````````1T-#.B`H1&5B:6%N(#$S+C(N,"TQ.2D@,3,N,BXP```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````8`P```````!@#````````'```````````````````
M``$````````````````````3````!P````(`````````.`,````````X`P``
M`````"`````````````````````(````````````````````)@````<````"
M`````````%@#````````6`,````````D````````````````````!```````
M`````````````#D````'`````@````````!\`P```````'P#````````(```
M``````````````````0```````````````````!'````]O__;P(`````````
MH`,```````"@`P```````/``````````!@`````````(````````````````
M````40````L````"`````````)`$````````D`0```````"X"`````````<`
M```!````"``````````8`````````%D````#`````@````````!(#0``````
M`$@-````````;@0```````````````````$```````````````````!A````
M____;P(`````````MA$```````"V$0```````+H`````````!@`````````"
M``````````(`````````;@```/[__V\"`````````'`2````````<!(`````
M``"```````````<````!````"````````````````````'T````$`````@``
M``````#P$@```````/`2````````@`$````````&``````````@`````````
M&`````````"'````!````$(`````````<!0```````!P%````````/@$````
M````!@```!<````(`````````!@`````````D0````$````&```````````@
M`````````"`````````7````````````````````!```````````````````
M`(P````!````!@`````````@(````````"`@````````8`,`````````````
M`````!``````````$`````````"7`````0````8`````````@",```````"`
M(P````````@````````````````````(``````````@`````````H`````$`
M```&`````````)`C````````D",```````"\.@``````````````````$```
M`````````````````*8````!````!@````````!,7@```````$Q>````````
M"0````````````````````0```````````````````"L`````0````(`````
M`````&``````````8````````,!````````````````````0````````````
M````````M`````$````"`````````,"@````````P*````````#\````````
M````````````!````````````````````,(````!`````@````````#`H0``
M`````,"A````````<`8```````````````````@```````````````````#,
M````#@````,`````````Z+L```````#HJP````````@`````````````````
M```(``````````@`````````V`````\````#`````````/"[````````\*L`
M```````(````````````````````"``````````(`````````.0````&````
M`P````````#XNP```````/BK``````````(````````'``````````@`````
M````$`````````";`````0````,`````````^+T```````#XK0````````@"
M```````````````````(``````````@`````````[0````$````#````````
M``#``````````+`````````H````````````````````"```````````````
M`````/,````(`````P````````!`P````````"BP````````6```````````
M`````````"````````````````````#X`````0```#``````````````````
M```HL````````!\````````````````````!``````````$``````````0``
M``,`````````````````````````1[`````````!`0``````````````````
0`0``````````````````````
